==> zio-aws-ec2_2.13-5.17.125.1-sources.jar: zio/aws/ec2/model/DescribeVpcEndpointConnectionNotificationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeVpcEndpointConnectionNotificationsResponse(
    connectionNotificationSet: Option[
      Iterable[zio.aws.ec2.model.ConnectionNotification]
    ] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse = {
    import DescribeVpcEndpointConnectionNotificationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
      .builder()
      .optionallyWith(
        connectionNotificationSet.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.connectionNotificationSet)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse.ReadOnly =
    zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
      .wrap(buildAwsValue())
}
object DescribeVpcEndpointConnectionNotificationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse =
      zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse(
        connectionNotificationSet.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def connectionNotificationSet
        : Option[List[zio.aws.ec2.model.ConnectionNotification.ReadOnly]]
    def nextToken: Option[String]
    def getConnectionNotificationSet: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.ConnectionNotification.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "connectionNotificationSet",
      connectionNotificationSet
    )
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
  ) extends zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse.ReadOnly {
    override val connectionNotificationSet
        : Option[List[zio.aws.ec2.model.ConnectionNotification.ReadOnly]] =
      scala
        .Option(impl.connectionNotificationSet())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.ConnectionNotification.wrap(item)
          }.toList
        )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
  ): zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.8.4-sources.jar: zio/aws/ec2/model/DescribeVpcEndpointConnectionNotificationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeVpcEndpointConnectionNotificationsResponse(
    connectionNotificationSet: Optional[
      Iterable[zio.aws.ec2.model.ConnectionNotification]
    ] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse = {
    import DescribeVpcEndpointConnectionNotificationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
      .builder()
      .optionallyWith(
        connectionNotificationSet.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.connectionNotificationSet)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse.ReadOnly =
    zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
      .wrap(buildAwsValue())
}
object DescribeVpcEndpointConnectionNotificationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse =
      zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse(
        connectionNotificationSet.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def connectionNotificationSet
        : Optional[List[zio.aws.ec2.model.ConnectionNotification.ReadOnly]]
    def nextToken: Optional[String]
    def getConnectionNotificationSet: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.ConnectionNotification.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "connectionNotificationSet",
      connectionNotificationSet
    )
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
  ) extends zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse.ReadOnly {
    override val connectionNotificationSet
        : Optional[List[zio.aws.ec2.model.ConnectionNotification.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.connectionNotificationSet())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.ConnectionNotification.wrap(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse
  ): zio.aws.ec2.model.DescribeVpcEndpointConnectionNotificationsResponse.ReadOnly =
    new Wrapper(impl)
}
